@@ -3,7 +3,7 @@ package SockJS;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use overload '&{}' => sub { shift->to_app(@_) }, fallback => 1;
 
@@ -317,6 +317,10 @@ See C<example/> directory.
 
 =head1 CREDITS
 
+Matthew Lien (github/BlueT)
+
+Mohammad S Anwar (github/manwar)
+
 =head1 AUTHOR
 
 Viacheslav Tykhanovskyi, C<vti@cpan.org>.
